==> haskell-network-run-0.3.0-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-run.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-run
version:              0.3.0
visibility:           public
id:                   network-run-0.3.0-KHbuT4BLRPc9B7cgXOXUpq
key:                  network-run-0.3.0-KHbuT4BLRPc9B7cgXOXUpq
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Simple network runner library
description:          Simple functions to run network clients and servers.
category:             Network
abi:                  671052327c474c024f1c08f08264e702
exposed:              True
exposed-modules:
    Network.Run.TCP Network.Run.TCP.Timeout Network.Run.UDP

hidden-modules:       Network.Run.Core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-run
hs-libraries:         HSnetwork-run-0.3.0-KHbuT4BLRPc9B7cgXOXUpq
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-6CSLlS2XYBeLlFfm0MgCfu
    time-manager-0.0.1-FZH5Qt40crLHp9ELRBj0am

haddock-interfaces:   /usr/share/doc/haskell-network-run/html/network-run.haddock
haddock-html:         /usr/share/doc/haskell-network-run/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-run-0.3.0-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-run.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-run
version:              0.3.0
visibility:           public
id:                   network-run-0.3.0-7YHgYCxvhJdLN8TAlScY0x
key:                  network-run-0.3.0-7YHgYCxvhJdLN8TAlScY0x
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Simple network runner library
description:          Simple functions to run network clients and servers.
category:             Network
abi:                  edb1b02951b1c86a583d9b5354f809f6
exposed:              True
exposed-modules:
    Network.Run.TCP Network.Run.TCP.Timeout Network.Run.UDP

hidden-modules:       Network.Run.Core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-run-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-run
hs-libraries:         HSnetwork-run-0.3.0-7YHgYCxvhJdLN8TAlScY0x
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-6CSLlS2XYBeLlFfm0MgCfu
    time-manager-0.0.1-6wvqP4ScA4GJS6gCZ4Wv50

haddock-interfaces:   /usr/share/doc/haskell-network-run/html/network-run.haddock
haddock-html:         /usr/share/doc/haskell-network-run/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
